% EquibRelations_2parm.m
% Plots boundaries for amplification and dilution in alpha_in-alpha_ni
% parameter space. 
% Plots boundaries for amplification and dilution in K_n-K_i 
% parameter space. 


clear all 
scrsz = get(0,'ScreenSize');
figure('Position',[1 scrsz(4) scrsz(3)/2.5 scrsz(4)/2.8])
format long;
textsize =16;



%% alpha_in, alpha_ni parameter space 
    % Import density data for parameter values
    Knvals = importdata('EquibData/VaryAlphas_alphani.txt');
    Kivals = importdata('EquibData/VaryAlphas_alphain.txt');
    Den_P3i = importdata('EquibData/VaryAlphas_P3i.txt');
    Den_P3n = importdata('EquibData/VaryAlphas_P3n.txt');
    Den_P5i = importdata('EquibData/VaryAlphas_P5i.txt');
    Den_P5n = importdata('EquibData/VaryAlphas_P5n.txt');

subplot(1,2,1)
    hold on
    DnVals=Den_P5n-Den_P3n;
    DiVals=Den_P5i-Den_P3i;
    HH=contour(Knvals,Kivals,DnVals,[0 0],'--w','LineWidth',3);
    GG=contour(Knvals,Kivals,DiVals,[0 0],'--w','LineWidth',3);
    plot(GG(1,2:end),GG(2,2:end),'-r','LineWidth',3);
    plot(HH(1,2:end),HH(2,2:end),'-b','LineWidth',3);
    plot(2.63,-0.286,'ok','LineWidth',3);
    ylim([-1 0.11])
    xlim([0 7])
    set(gca,'Box','on','FontSize',16)
    set(gca,'XTick',[0 2 4 6],'YTick',[-1 -0.5 0])
    xlabel('\alpha_{ni}','FontSize',18)
    ylabel('\alpha_{in}','FontSize',18)
    title('')
    text(0,0.15,'(A)','FontSize',16,'FontWeight','Bold')
    text(0.1,-0.5,'[A,A]','FontSize',12,'FontWeight','Bold')
    text(5,-0.5,'[D,A]','FontSize',12,'FontWeight','Bold')
    text(6,0.055,'[D,D]','FontSize',12,'FontWeight','Bold')
    text(0.5,0.055,'[A,D]','FontSize',12,'FontWeight','Bold')
    
    
    
    
%% K_i, K_n parameter space

    Knvals = importdata('EquibData/VaryKs_Kn.txt');
    Kivals = importdata('EquibData/VaryKs_Ki.txt');
    Den_P3i = importdata('EquibData/VaryKs_P3i.txt');
    Den_P3n = importdata('EquibData/VaryKs_P3n.txt');
    Den_P5i = importdata('EquibData/VaryKs_P5i.txt');
    Den_P5n = importdata('EquibData/VaryKs_P5n.txt');

subplot(1,2,2)
    hold on
    DnVals=Den_P5n-Den_P3n;
    DiVals=Den_P5i-Den_P3i;
    HH=contour(Knvals,Kivals,DnVals,[0 0],'--w','LineWidth',3);
    II=contour(Knvals,Kivals,Den_P5n,[0,0],'--w','LineWidth',3);
    plot(HH(1,2:end),HH(2,2:end),'-b','LineWidth',3);
    plot(II(1,2:end),II(2,2:end),'-k','LineWidth',3);
    plot(97.5,12.8,'ok','LineWidth',3)
    ylim([5 39])
    xlim([43 500])
    set(gca,'Box','on','FontSize',16)
    set(gca,'XTick',[50 200 350 500],'YTick',[5 15 25 35])
    xlabel('K_n','FontSize',18)
    ylabel('K_i','FontSize',18)
    title('')
    text(43,40,'(B)','FontSize',16,'FontWeight','Bold')
    text(300,23,'[D,A]','FontSize',12,'FontWeight','Bold')
    text(110,6.6,'[A,A]','FontSize',12,'FontWeight','Bold')
    
    
annotation('arrow',[0.624995265151515 0.590790719696968],...
    [0.2 0.2],'LineWidth',2);
