%%% EquibRelations.m
% Plots equilibrium densities as functions of alpha_in, alpha_ni

clear all
figure;
format long
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Varying alpha_in
    % Import density data for parameter values
    alphainvals = importdata('EquibData/VaryAlphain_alphain.txt');
    Den_Ain_P3i = importdata('EquibData/VaryAlphain_P3i.txt');
    Den_Ain_P3n = importdata('EquibData/VaryAlphain_P3n.txt');
    Den_Ain_P5 = importdata('EquibData/VaryAlphain_P5.txt');
    
    subplot(2,2,1)
    hold on
    plot(alphainvals,Den_Ain_P3n(:,2),'--k','Linewidth',3)
    plot(alphainvals,Den_Ain_P5(:,2),'-k','Linewidth',3)
    plot([-0.286 -0.286],[0 30],'-k','Linewidth',1);
    xlim([-0.4 0.11])
    ylim([0 30])
    set(gca,'Box','on','FontSize',16)
    set(gca,'XTick',[-0.4 -0.2  0 ],'YTick',[0 15 30])
    ylabel('Native Infected Density')
    xlabel('\alpha_{in}')
    title('A')
    
    subplot(2,2,2)
    hold on
    plot(alphainvals,Den_Ain_P3i(:,2),'--k','Linewidth',3)
    plot(alphainvals,Den_Ain_P5(:,4),'-k','Linewidth',3)
    plot([-0.286 -0.286],[0 30],'-k','Linewidth',1);
    xlim([-0.4 0.1])
    ylim([0 20])
    set(gca,'Box','on','FontSize',16)
     set(gca,'XTick',[-0.4 -0.2  0 ],'YTick',[0 10 20])
    ylabel('Invasive Infected Density')
    xlabel('\alpha_{in}')
    title('B')
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Varying alpha_ni
    % Get data
    alphanivals = importdata('EquibData/VaryAlphani_alphani.txt');
    Den_Ani_P3i = importdata('EquibData/VaryAlphani_P3i.txt');
    Den_Ani_P3n = importdata('EquibData/VaryAlphani_P3n.txt');
    Den_Ani_P5 = importdata('EquibData/VaryAlphani_P5.txt');
    
    subplot(2,2,3)
    hold on
    plot(alphanivals,Den_Ani_P3n(:,2),'--k','Linewidth',3)
    plot(alphanivals,Den_Ani_P5(:,2),'-k','Linewidth',3)
    plot([2.63 2.63],[0 60],'-k','Linewidth',1);
    xlim([0 7])
    ylim([0 60])
    set(gca,'Box','on','FontSize',16)
    set(gca,'XTick',[0 2 4 6],'YTick',[0 20 40 60])
    ylabel('Native Infected Density')
    xlabel('\alpha_{ni}')
    title('C')
    
    subplot(2,2,4)
    hold on
    plot(alphanivals,Den_Ani_P3i(:,2),'--k','Linewidth',3)
    plot(alphanivals,Den_Ani_P5(:,4),'-k','Linewidth',3)
    plot([2.63 2.63],[0 30],'-k','Linewidth',1);
    xlim([0 7])
    ylim([0 30])
    set(gca,'Box','on','FontSize',16)
    set(gca,'XTick',[0 2 4 6],'YTick',[0 10 20 30])
    ylabel('Invasive Infected Density')
    xlabel('\alpha_{ni}')
    title('D')    
