% LongTermDensityEstimates_script
% For each treatment aligns times series, computes the average, 
% plots aligned time series, and estimates average long-term density

clear all
scrsz = get(0,'ScreenSize');
figure('Position',[1 scrsz(4) scrsz(3)/1.5 scrsz(4)/1.5])
textsize =16;

Time = 7:5:52;
Times = 0:5:95;

MeanEndDen = zeros(4,6); % Average long-term densities
        % Columns are treatments: N, N+D, I, I+D, C, C+D
        % Rows are densities: N_uninfect, N_infect, I_uninfect, I_infect
StdEndDen = zeros(4,6); % Variance of long-term densities

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Native, No Disease
    % Get data
    DataNative = xlsread('Mesocosm data.xls','dent-only treatments','');
    DataN = zeros(10,10);
    for jj =1:10;
        DataN(10:-1:1,jj) = DataNative((1:10)+(jj-1)*10,12);
    end
    for jj = 1:10
        AvgN0(jj) = mean(DataN(jj,1:10));
    end
    
    % Shift data so that peaks align
    ShiftDataN = NaN(20,10);
    AvgShiftN0 = NaN(20,1);
    AvgShiftN = NaN(20,1);
    
    for jj =1:10;
        zz = find(DataN(1:10,jj)==max(DataN(1:10,jj)));
        ShiftDataN((10-(zz-1)):(20-(zz)),jj) = DataN(1:10,jj);
    end

    % Exclude 2,4,9,10 for double peaks    
    keepN = [1 3 5 7 8];
    for jj = 1:20;
        zz = find(ShiftDataN(jj,:)>-1);
        AvgShiftN0(jj) = mean(ShiftDataN(jj,zz));
        zz = find(ShiftDataN(jj,keepN)>-1);
        AvgShiftN(jj) = mean(ShiftDataN(jj,keepN(zz)));
    end
    
    % Estimate of Long Term Density
    MeanEndDen(1,1) = mean(AvgShiftN(14:15));   
    StdEndDen(1,1) = std(AvgShiftN(14:15));
    
    % Plot shifted time series
    subplot(2,4,1)
    hold on
    for jj =keepN;
        zztemp = find(ShiftDataN(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataN(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftN,'-b','LineWidth',3)
    xlim([0 95])
    ylim([0 1200])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 400 800 1200])
    xlabel('Day (shifted)')
    ylabel('Density (num./L)')
    title('Native, No Disease')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Invasive, No Disease
    % Get data
    DataInvader = xlsread('LumOnly.xls');
    DataI = zeros(10,10);
    for jj =1:10;
        DataI(10:-1:1,jj) = DataInvader((1:10)+(jj-1)*10,12);
    end
    for jj = 1:10
        AvgI0(jj) = mean(DataI(jj,1:10));
    end
    
    % Shift data so that peaks align
    ShiftDataI = NaN(20,10);
    AvgShiftI0 = NaN(20,1);
    AvgShiftI = NaN(20,1);
    
    for jj =1:10;
        zz = find(DataI(1:10,jj)==max(DataI(1:10,jj)));
        ShiftDataI((10-(zz-1)):(20-(zz)),jj) = DataI(1:10,jj);
    end
    
    % Exclude 2 because zero density at end
    % Exclude 6 because of double peak
    keepI = [1 3:5 7:10];
    for jj = 1:20;
        zz = find(ShiftDataI(jj,:)>-1);
        AvgShiftI0(jj) = mean(ShiftDataI(jj,zz));
        zz = find(ShiftDataI(jj,keepI)>-1);
        AvgShiftI(jj) = mean(ShiftDataI(jj,keepI(zz)));
    end
    
    % Estimate of Long Term Density
    MeanEndDen(3,3) = mean(AvgShiftI(14:15));   
    StdEndDen(3,3) = std(AvgShiftI(14:15));
    
    % Plot shifted time series
    subplot(2,4,2)
    hold on
    for jj =keepI;
        zztemp = find(ShiftDataI(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataI(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftI,'-b','LineWidth',3)
    xlim([0 95])
    ylim([0 600])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 200 400 600])
    xlabel('Day (shifted)')
    ylabel('Density (num./L)')
    title('Invasive, No Disease')
      
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Native + Disease
% Get data
    DataNtot = zeros(10,8); 
    DataNi = zeros(10,8);
    for jj =1:8;
        DataNtot(10:-1:1,jj) = DataNative((1:10)+(jj-1)*10+100,12);
        DataNi(10:-1:1,jj) = DataNative((1:10)+(jj-1)*10+100,13);
    end
    for jj = 1:10
        AvgNn0(jj) = mean(DataNtot(jj,1:8));
        AvgNi0(jj) = mean(DataNi(jj,1:8));
    end
    
    % Shift data so that peaks align
    ShiftDataNtot = NaN(20,8);
    ShiftDataNi = NaN(20,8);
    AvgShiftNtot0 = NaN(20,1);
    AvgShiftNtot = NaN(20,1);
    AvgShiftNi0 = NaN(20,1);
    AvgShiftNi = NaN(20,1);
    
    for jj =1:8;
        zz = find(DataNtot(:,jj)==max(DataNtot(:,jj)));
        ShiftDataNtot((10-(zz-1)):(20-(zz)),jj) = DataNtot(:,jj);
        ShiftDataNi((10-(zz-1)):(20-(zz)),jj) = DataNi(:,jj);
    end

    keepNn = 1:8;
    for jj = 1:20;
        zz = find(ShiftDataNtot(jj,:)>-1);
        AvgShiftNtot0(jj) = mean(ShiftDataNtot(jj,zz));
        AvgShiftNi0(jj) = mean(ShiftDataNi(jj,zz));
        zz = find(ShiftDataNtot(jj,keepNn)>-1);
        AvgShiftNtot(jj) = mean(ShiftDataNtot(jj,keepNn(zz)));
        AvgShiftNi(jj) = mean(ShiftDataNi(jj,keepNn(zz)));
    end
    MeanEndDen(1,2) = mean(AvgShiftNtot(15:16)-AvgShiftNi(15:16));   
    MeanEndDen(2,2) = mean(AvgShiftNi(15:16));   
    StdEndDen(1,2) = std(AvgShiftNtot(15:16)-AvgShiftNi(15:16));
    StdEndDen(2,2) = std(AvgShiftNi(15:16));
    
    % Plot shifted time series
    subplot(2,4,5)
    hold on
    for jj =keepNn;
        zztemp = find(ShiftDataNtot(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataNtot(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftNtot,'-b','LineWidth',3)
    plot(Times,AvgShiftNi,'-r','LineWidth',3)
    xlim([0 95])
    ylim([0 900])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 300 600 900])
    xlabel('Day (shifted)')
    ylabel('Density (num./L)')
    title('Native + Disease')
 
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Invasive + Disease
    % Get data 
    % Excluded 6 for double peak
    DataItot = zeros(10,9);
    DataIi = zeros(10,9);
    for jj =1:9;
        DataItot(10:-1:1,jj) = DataInvader((1:10)+(jj-1)*10+100,12);
        DataIi(10:-1:1,jj) = DataInvader((1:10)+(jj-1)*10+100,13);
    end
    for jj = 1:10
        AvgIn0(jj) = mean(DataItot(jj,1:8));
        AvgIi0(jj) = mean(DataIi(jj,1:8));
    end
    
    % Shift data so that peaks align
    ShiftDataItot = NaN(20,9);
    ShiftDataIi = NaN(20,9);
    AvgShiftItot0 = NaN(20,1);
    AvgShiftItot = NaN(20,1);
    AvgShiftIi0 = NaN(20,1);
    AvgShiftIi = NaN(20,1);
    
    for jj =1:9;
        zz = find(DataItot(:,jj)==max(DataItot(:,jj)));
        ShiftDataItot((10-(zz-1)):(20-(zz)),jj) = DataItot(:,jj);
        ShiftDataIi((10-(zz-1)):(20-(zz)),jj) = DataIi(:,jj);
    end
    
    keepIn = [1:5 7:9];
    for jj = 1:20;
        zz = find(ShiftDataItot(jj,:)>-1);
        AvgShiftItot0(jj) = mean(ShiftDataItot(jj,zz));
        AvgShiftIi0(jj) = mean(ShiftDataIi(jj,zz));
        zz = find(ShiftDataItot(jj,keepIn)>-1);
        AvgShiftItot(jj) = mean(ShiftDataItot(jj,keepIn(zz)));
        AvgShiftIi(jj) = mean(ShiftDataIi(jj,keepIn(zz)));
    end
    
    
    % Estimate of Long Term Density
    MeanEndDen(3,4) = mean(AvgShiftItot(14:15)-AvgShiftIi(14:15));
    MeanEndDen(4,4) = mean(AvgShiftIi(14:15));   
    StdEndDen(3,4) = std(AvgShiftItot(14:15)-AvgShiftIi(14:15));
    StdEndDen(4,4) = std(AvgShiftIi(14:15));
         
    % Plot shifted time series
    subplot(2,4,6)
    hold on
    for jj =keepIn;
        zztemp = find(ShiftDataItot(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataItot(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftItot,'-b','LineWidth',3)
    plot(Times,AvgShiftIi,'-r','LineWidth',3)
    xlim([0 95])
    ylim([0 400])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 200 400])
    xlabel('Day (shifted)')
    ylabel('Density (num./L)')
    title('Invasive + Disease')
    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Combined, No Disease
    % Get data 
    DataCombined = xlsread('Mesocosm data1.xls');
       
    DataCN = zeros(10,10);
    for ii =1:10;
        DataCN(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10,20);
        DataCI(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10,21);
    end
    for ii = 1:10
        AvgCN0(ii) = mean(DataCN(ii,:));
        AvgCI0(ii) = mean(DataCI(ii,:));
    end
    
    % Shift data so that native peaks align
    ShiftDataCN = NaN(20,10);
    AvgShiftCN0 = NaN(20,1);
    AvgShiftCN = NaN(20,1);
    ShiftDataCI = NaN(20,10);
    AvgShiftCI0 = NaN(20,1);
    AvgShiftCI = NaN(20,1);
    
    for jj =1:10;
        zz = find(DataCN(:,jj)==max(DataCN(:,jj)));
        ShiftDataCN((10-(zz-1)):(20-(zz)),jj) = DataCN(:,jj);
        ShiftDataCI((10-(zz-1)):(20-(zz)),jj) = DataCI(:,jj);
    end
    
    % Exclude 5 because of double peak in native
    keepCN = [1:4 6:10];
    for jj = 1:20;
        zz = find(ShiftDataCN(jj,:)>-1);
        AvgShiftCN0(jj) = mean(ShiftDataCN(jj,zz));
        zz = find(ShiftDataCN(jj,keepCN)>-1);
        AvgShiftCN(jj) = mean(ShiftDataCN(jj,keepCN(zz)));
        zz = find(ShiftDataCI(jj,:)>-1);
        AvgShiftCI0(jj) = mean(ShiftDataCI(jj,zz));
        zz = find(ShiftDataCI(jj,keepCN)>-1);
        AvgShiftCI(jj) = mean(ShiftDataCI(jj,keepCN(zz)));
    end
    
    % Estimate of Long Term Density
    MeanEndDen(1,5) = mean(AvgShiftCN(14:15));
    MeanEndDen(3,5) = mean(AvgShiftCI(14:15));   
    StdEndDen(1,5) = std(AvgShiftCN(14:15));
    StdEndDen(3,5) = std(AvgShiftCI(14:15));
    
    % Plot shifted time series
    % Native Densities
    subplot(2,4,3)
    hold on
    for jj =keepCN;
        zztemp = find(ShiftDataCN(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataCN(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftCN,'-b','LineWidth',3)
    xlim([0 95])
    ylim([0 600])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 200 400 600])
    xlabel('Day (shifted)')
    ylabel('Native Density (num./L)')
    title('Combined, No Disease')
        
    % Invasive Densities
    subplot(2,4,4)
    hold on
    for jj =keepCN;
        zztemp = find(ShiftDataCI(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataCI(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftCI,'-b','LineWidth',3)
    xlim([0 95])
    ylim([0 300])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 100 200 300])
    xlabel('Day (shifted)')
    ylabel('Invasive Density (num./L)')
    title('Combined, No Disease')

    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Combined + Disease
    % Get data 
    DataCombined = xlsread('Mesocosm data1.xls');
       
    DataCNtot = zeros(10,8); DataCItot = zeros(10,8);
    DataCNi = zeros(10,8); DataCIitot = zeros(10,8);
    for ii =1:8;
        DataCNtot(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10+90,20);
        DataCItot(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10+90,21);
        DataCNi(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10+90,22);
        DataCIitot(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10+90,23);
    end
    for ii = 1:10
        AvgCNtot0(ii) = mean(DataCNtot(ii,:));
        AvgCItot0(ii) = mean(DataCItot(ii,:));
        AvgCNitot0(ii) = mean(DataCNi(ii,:));
        AvgCIitot0(ii) = mean(DataCIitot(ii,:));
    end
    
    % Shift data so that Native peaks align
    ShiftDataCNtot = NaN(20,10);
    ShiftDataCNi = NaN(20,10);
    AvgShiftCNtot0 = NaN(20,1);
    AvgShiftCNi0 = NaN(20,1);
    AvgShiftCNtot = NaN(20,1);
    AvgShiftCNi = NaN(20,1);
    ShiftDataCItot = NaN(20,10);
    ShiftDataCIi = NaN(20,10);
    AvgShiftCItot0 = NaN(20,1);
    AvgShiftCIi0 = NaN(20,1);
    AvgShiftCItot = NaN(20,1);
    AvgShiftCIi = NaN(20,1);
         
    for jj =1:8;
        zz = find(DataCNtot(:,jj)==max(DataCNtot(:,jj)));
        ShiftDataCNtot((10-(zz-1)):(20-(zz)),jj) = DataCNtot(:,jj);
        ShiftDataCNi((10-(zz-1)):(20-(zz)),jj) = DataCNi(:,jj);
        ShiftDataCItot((10-(zz-1)):(20-(zz)),jj) = DataCItot(:,jj);
        ShiftDataCIi((10-(zz-1)):(20-(zz)),jj) = DataCIitot(:,jj);      
    end

    % Exclude #8 because of double peak
    keepCN = 1:7;
    for jj = 1:20;
        zz = find(ShiftDataCNtot(jj,:)>-1);
        AvgShiftCNtot0(jj) = mean(ShiftDataCNtot(jj,zz));
        AvgShiftCNi0(jj) = mean(ShiftDataCNi(jj,zz));
        zz = find(ShiftDataCNtot(jj,keepCN)>-1);
        AvgShiftCNtot(jj) = mean(ShiftDataCNtot(jj,keepCN(zz)));
        AvgShiftCNi(jj) = mean(ShiftDataCNi(jj,keepCN(zz)));
        zz = find(ShiftDataCItot(jj,:)>-1);
        AvgShiftCItot0(jj) = mean(ShiftDataCItot(jj,zz));
        AvgShiftCIi0(jj) = mean(ShiftDataCIi(jj,zz));
        zz = find(ShiftDataCItot(jj,keepCN)>-1);
        AvgShiftCItot(jj) = mean(ShiftDataCItot(jj,keepCN(zz)));
        AvgShiftCIi(jj) = mean(ShiftDataCIi(jj,keepCN(zz)));
    end
    
    % Estimate of Long Term Density    
    MeanEndDen(1,6) = mean(AvgShiftCNtot(15:16)-AvgShiftCNi(15:16));
    MeanEndDen(2,6) = mean(AvgShiftCNi(15:16));   
    MeanEndDen(3,6) = mean(AvgShiftCItot(15:16)-AvgShiftCIi(15:16));
    MeanEndDen(4,6) = mean(AvgShiftCIi(15:16));   
    StdEndDen(1,6) = std(AvgShiftCNtot(15:16)-AvgShiftCNi(15:16));
    StdEndDen(2,6) = std(AvgShiftCNi(15:16));
    StdEndDen(3,6) = std(AvgShiftCItot(15:16)-AvgShiftCIi(15:16));
    StdEndDen(4,6) = std(AvgShiftCIi(15:16));
    
    % Plot shifted time series
    % Native Densities
    subplot(2,4,7)
    hold on
    for jj =keepCN;
        zztemp = find(ShiftDataCNtot(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataCNtot(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftCNtot,'-b','LineWidth',3)
    plot(Times,AvgShiftCNi,'-r','LineWidth',3)
        xlim([0 95])
    ylim([0 800])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 400 800])
    xlabel('Day (shifted)')
    ylabel('Native Density (num./L)')
    title('Combined + Disease')
        
    % Invasive Densities
    subplot(2,4,8)
    hold on 
    for jj =keepCN;
        zztemp = find(ShiftDataCItot(:,jj)>-0.5);
        plot(Times(zztemp),ShiftDataCItot(zztemp,jj),'-k','LineWidth',2);
    end
    plot(Times,AvgShiftCItot,'-b','LineWidth',3)
    plot(Times,AvgShiftCIi,'-r','LineWidth',3)
        xlim([0 95])
    ylim([0 300])
    set(gca,'Box','on','FontSize',16);
    set(gca,'XTick',[0 45 90],'YTick',[0 100 200 300])
    xlabel('Day (shifted)')
    ylabel('Invasive Density (num./L)')
    title('Combined + Disease')
    
%% Show Mean and Std of Estimate Long Term Densities
   % Values are recorded in Table S5
    MeanEndDen'
    StdEndDen'
